summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/parameters/RosegardenParameterArea.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/parameters/RosegardenParameterArea.cpp')
-rw-r--r--src/gui/editors/parameters/RosegardenParameterArea.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/gui/editors/parameters/RosegardenParameterArea.cpp b/src/gui/editors/parameters/RosegardenParameterArea.cpp
index 5e13652..8a7fcd3 100644
--- a/src/gui/editors/parameters/RosegardenParameterArea.cpp
+++ b/src/gui/editors/parameters/RosegardenParameterArea.cpp
@@ -35,7 +35,7 @@
#include <tqscrollview.h>
#include <tqstring.h>
#include <tqvbox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqvgroupbox.h>
#include <tqwidget.h>
#include <tqwidgetstack.h>
@@ -86,15 +86,15 @@ void RosegardenParameterArea::addRosegardenParameterBox(
m_parameterBoxes.push_back(b);
m_scrollView->setMinimumWidth(std::max(m_scrollView->minimumWidth(),
- b->tqsizeHint().width()) + 8);
+ b->sizeHint().width()) + 8);
// Create a titled group box for the parameter box, parented by the
// classic tqlayout widget, so that it can be used to provide a title
// and outline, in classic mode. Add this container to an array that
// parallels the above array of parameter boxes.
TQVGroupBox *box = new TQVGroupBox(b->getLongLabel(), m_classic);
- box->tqlayout()->setMargin( 4 ); // about half the default value
+ box->layout()->setMargin( 4 ); // about half the default value
TQFont f;
f.setBold( true );
box->setFont( f );
@@ -86,15 +86,15 @@ void RosegardenParameterArea::addRosegardenParameterBox(
// Create a titled group box for the parameter box, parented by the
- // classic tqlayout widget, so that it can be used to provide a title
+ // classic layout widget, so that it can be used to provide a title
// and outline, in classic mode. Add this container to an array that
// parallels the above array of parameter boxes.